@@ -1,6 +1,7 @@
 package Pcore::App::Nginx;
 
 use Pcore -class;
+use Pcore::Nginx;
 
 extends qw[Pcore::App::Alien];
 
@@ -16,12 +17,16 @@ our $CFG = {
 };
 
 # CLI
-sub cli_name ($self) {
-    return 'nginx';
-}
+around CLI => sub ( $orig, $self ) {
+    my $cli = $self->$orig;
+
+    $cli->{name} = 'nginx';
+
+    return $cli;
+};
 
 sub _build_nginx_ver ($self) {
-    return $self->cfg->{NGINX}->{NGINX_VER} || $ENV->{CFG}->{NGINX}->{NGINX_VER};
+    return $self->cfg->{NGINX}->{NGINX_VER} || $ENV->get_dist('pcore-nginx')->cfg->{NGINX}->{NGINX_VER};
 }
 
 # APP
@@ -116,7 +121,7 @@ around app_build => sub ( $orig, $self ) {
 
         # pcre
         P->http->get(
-            qq[http://nchc.dl.sourceforge.net/project/pcre/pcre/$ENV->{CFG}->{NGINX}->{PCRE_VER}/pcre-$ENV->{CFG}->{NGINX}->{PCRE_VER}.tar.gz],
+            qq[http://netcologne.dl.sourceforge.net/project/pcre/pcre/@{[$ENV->get_dist('pcore-nginx')->cfg->{NGINX}->{PCRE_VER}]}/pcre-@{[$ENV->get_dist('pcore-nginx')->cfg->{NGINX}->{PCRE_VER}]}.tar.gz],
             buf_size    => 1,
             cv          => $cv,
             on_progress => 1,
@@ -165,7 +170,7 @@ around app_build => sub ( $orig, $self ) {
                 '--with-http_sub_module',
                 '--with-http_gzip_static_module',
                 '--with-http_perl_module',
-                '--with-pcre=' . $build_dir . 'pcre-' . $ENV->{CFG}->{NGINX}->{PCRE_VER},
+                '--with-pcre=' . $build_dir . 'pcre-' . $ENV->get_dist('pcore-nginx')->cfg->{NGINX}->{PCRE_VER},
                 '--with-pcre-jit',
                 map { '--add-module=' . $build_dir . $module->{$_}->{path} } grep { $module->{$_}->{enabled} } keys $module->%*,
             );
@@ -213,6 +218,8 @@ around app_test => sub ( $orig, $self ) {
 
     if ( $out =~ /test\hfailed/sm ) {
         say 'FAILED';
+
+        exit 1;
     }
     else {
         say 'OK';
@@ -232,9 +239,9 @@ sub generate_alien_cfg ($self) {
         alien_dir          => $self->alien_dir,
         log_dir            => $ENV->{LOG_DIR},
         vhosts_dir         => $self->app_dir . 'vhosts',
-        geoip_country_path => $ENV->res->get('/data/geoip_country.dat'),
-        geoip_city_path    => $ENV->res->get('/data/geoip_city.dat'),
-        ssl                => 0,                                           # $self->openssl->is_enabled, # TODO
+        geoip_country_path => $ENV->share->get('/data/geoip_country.dat'),
+        geoip_city_path    => $ENV->share->get('/data/geoip_city.dat'),
+        ssl                => 0,                                             # $self->openssl->is_enabled, # TODO
     };
 
     $cfg = P->tmpl( type => 'text' )->render( 'nginx/server.nginx', $params );
@@ -299,7 +306,7 @@ sub alien_proc ($self) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 131, 170             │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 136, 175             │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
