@@ -1,6 +1,7 @@
-package Pcore::Nginx v0.2.6;
+package Pcore::Nginx v0.3.0;
 
-use Pcore -class;
+use Pcore -dist;
+use Pcore::GeoIP;
 
 1;
 __END__
